@@ -5,10 +5,10 @@ from git import GitCommandError
 @click.command()
 @click.pass_context
 @click.option('-m', '--message', 'message', help='Commit message')
-@click.option('-p', '--push', is_flag=True, help='Push to remote repository')
-def save(ctx, message, push):
+@click.option('-l', '--local', is_flag=True, help='Save locally only')
+def save(ctx, message, local):
     '''
-    Git add ., git commit -m, git pull, git push if possible
+    Creates checkpoint of your project
     '''
     # Recover repo from context
     repo = ctx.obj['REPO']
@@ -28,7 +28,7 @@ def save(ctx, message, push):
         except GitCommandError:
             click.echo("No changes in local repository since last commit")
 
-        if push:
+        if not local:
             if repo.remotes.origin.exists():
                 try:
                     repo.git.pull()
@@ -72,4 +72,4 @@ def get_conflict_files(repo):
         repo.git.diff("--check")
     except GitCommandError as e:
         matched_lines = [line for line in e.stdout.split("'")[1].split('\n') if "conflict" in line]
-    return matched_lines
\ No newline at end of file
+    return matched_lines
